package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.CodeList;
import com.sa.ibiz.demo.demo.service.CodeListService;
import com.sa.ibiz.demo.demo.service.dto.CodeListSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/codelist")
public class CodeListResource
{
	@Autowired
	private CodeListService service;


	@GetMapping(value = "/{id}")
	public ResponseEntity<CodeList> get(@Validated @PathVariable String id){
		CodeList data=new CodeList();
		data.setCodelistid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("代码表[get]操作发生错误","CodeList",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<CodeList> remove(@Validated @RequestBody CodeList data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("代码表[remove]操作发生错误","CodeList",data.getCodelistid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<CodeList> update(@Validated @RequestBody CodeList data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("代码表[update]操作发生错误","CodeList",data.getCodelistid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<CodeList> getDraft(@Validated @RequestBody CodeList data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("代码表[getDraft]操作发生错误","CodeList","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/checkKey")
	public ResponseEntity<CodeList> checkKey(@Validated @RequestBody CodeList data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("代码表[checkKey]操作发生错误","CodeList",data.getCodelistid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/refreshModel")
	public ResponseEntity<CodeList> refreshModel(@Validated @RequestBody CodeList data){
		service.refreshModel(data);
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/create")
	public ResponseEntity<CodeList> create(@Validated @RequestBody CodeList data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("代码表[create]操作发生错误","CodeList",data.getCodelistid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<CodeList>> searchDefaultPage(@Validated @RequestBody CodeListSearchFilter filter){
		Page<CodeList> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<CodeList>> listDefault(@Validated @RequestBody CodeListSearchFilter filter){
		List<CodeList> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
