package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.DataEntity;
import com.sa.ibiz.demo.demo.service.DataEntityService;
import com.sa.ibiz.demo.demo.service.dto.DataEntitySearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/dataentity")
public class DataEntityResource
{
	@Autowired
	private DataEntityService service;


	@PostMapping(value = "/checkKey")
	public ResponseEntity<DataEntity> checkKey(@Validated @RequestBody DataEntity data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("实体[checkKey]操作发生错误","DataEntity",data.getDeid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<DataEntity> getDraft(@Validated @RequestBody DataEntity data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("实体[getDraft]操作发生错误","DataEntity","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<DataEntity> remove(@Validated @RequestBody DataEntity data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("实体[remove]操作发生错误","DataEntity",data.getDeid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/initAll")
	public ResponseEntity<DataEntity> initAll(@Validated @RequestBody DataEntity data){
		service.initAll(data);
		return ResponseEntity.ok().body(data);
	}
	@GetMapping(value = "/{id}")
	public ResponseEntity<DataEntity> get(@Validated @PathVariable String id){
		DataEntity data=new DataEntity();
		data.setDeid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("实体[get]操作发生错误","DataEntity",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/create")
	public ResponseEntity<DataEntity> create(@Validated @RequestBody DataEntity data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("实体[create]操作发生错误","DataEntity",data.getDeid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/initUserRoleData")
	public ResponseEntity<DataEntity> initUserRoleData(@Validated @RequestBody DataEntity data){
		service.initUserRoleData(data);
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<DataEntity> update(@Validated @RequestBody DataEntity data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("实体[update]操作发生错误","DataEntity",data.getDeid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<DataEntity>> searchDefaultPage(@Validated @RequestBody DataEntitySearchFilter filter){
		Page<DataEntity> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<DataEntity>> listDefault(@Validated @RequestBody DataEntitySearchFilter filter){
		List<DataEntity> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
