package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.File;
import com.sa.ibiz.demo.demo.service.FileService;
import com.sa.ibiz.demo.demo.service.dto.FileSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/file")
public class FileResource
{
	@Autowired
	private FileService service;


	@PostMapping(value = "/create")
	public ResponseEntity<File> create(@Validated @RequestBody File data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("文件[create]操作发生错误","File",data.getFileid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<File> remove(@Validated @RequestBody File data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("文件[remove]操作发生错误","File",data.getFileid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<File> getDraft(@Validated @RequestBody File data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("文件[getDraft]操作发生错误","File","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<File> update(@Validated @RequestBody File data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("文件[update]操作发生错误","File",data.getFileid().toString());
		return ResponseEntity.ok().body(data);
	}
	@GetMapping(value = "/{id}")
	public ResponseEntity<File> get(@Validated @PathVariable String id){
		File data=new File();
		data.setFileid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("文件[get]操作发生错误","File",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/checkKey")
	public ResponseEntity<File> checkKey(@Validated @RequestBody File data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("文件[checkKey]操作发生错误","File",data.getFileid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<File>> searchDefaultPage(@Validated @RequestBody FileSearchFilter filter){
		Page<File> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<File>> listDefault(@Validated @RequestBody FileSearchFilter filter){
		List<File> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
