package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.MsgAccount;
import com.sa.ibiz.demo.demo.service.MsgAccountService;
import com.sa.ibiz.demo.demo.service.dto.MsgAccountSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/msgaccount")
public class MsgAccountResource
{
	@Autowired
	private MsgAccountService service;


	@PostMapping(value = "/getDraft")
	public ResponseEntity<MsgAccount> getDraft(@Validated @RequestBody MsgAccount data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("消息账户[getDraft]操作发生错误","MsgAccount","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/checkKey")
	public ResponseEntity<MsgAccount> checkKey(@Validated @RequestBody MsgAccount data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("消息账户[checkKey]操作发生错误","MsgAccount",data.getMsgaccountid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<MsgAccount> remove(@Validated @RequestBody MsgAccount data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("消息账户[remove]操作发生错误","MsgAccount",data.getMsgaccountid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<MsgAccount> update(@Validated @RequestBody MsgAccount data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("消息账户[update]操作发生错误","MsgAccount",data.getMsgaccountid().toString());
		return ResponseEntity.ok().body(data);
	}
	@GetMapping(value = "/{id}")
	public ResponseEntity<MsgAccount> get(@Validated @PathVariable String id){
		MsgAccount data=new MsgAccount();
		data.setMsgaccountid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("消息账户[get]操作发生错误","MsgAccount",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/create")
	public ResponseEntity<MsgAccount> create(@Validated @RequestBody MsgAccount data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("消息账户[create]操作发生错误","MsgAccount",data.getMsgaccountid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<MsgAccount>> searchDefaultPage(@Validated @RequestBody MsgAccountSearchFilter filter){
		Page<MsgAccount> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<MsgAccount>> listDefault(@Validated @RequestBody MsgAccountSearchFilter filter){
		List<MsgAccount> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
