package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.Services;
import com.sa.ibiz.demo.demo.service.ServicesService;
import com.sa.ibiz.demo.demo.service.dto.ServicesSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/services")
public class ServicesResource
{
	@Autowired
	private ServicesService service;


	@PostMapping(value = "/checkKey")
	public ResponseEntity<Services> checkKey(@Validated @RequestBody Services data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("服务[checkKey]操作发生错误","Services",data.getServiceid().toString());
		return ResponseEntity.ok().body(data);
	}
	@GetMapping(value = "/{id}")
	public ResponseEntity<Services> get(@Validated @PathVariable String id){
		Services data=new Services();
		data.setServiceid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("服务[get]操作发生错误","Services",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<Services> remove(@Validated @RequestBody Services data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("服务[remove]操作发生错误","Services",data.getServiceid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<Services> update(@Validated @RequestBody Services data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("服务[update]操作发生错误","Services",data.getServiceid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<Services> getDraft(@Validated @RequestBody Services data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("服务[getDraft]操作发生错误","Services","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/startService")
	public ResponseEntity<Services> startService(@Validated @RequestBody Services data){
		service.startService(data);
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/stopService")
	public ResponseEntity<Services> stopService(@Validated @RequestBody Services data){
		service.stopService(data);
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/create")
	public ResponseEntity<Services> create(@Validated @RequestBody Services data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("服务[create]操作发生错误","Services",data.getServiceid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<Services>> searchDefaultPage(@Validated @RequestBody ServicesSearchFilter filter){
		Page<Services> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<Services>> listDefault(@Validated @RequestBody ServicesSearchFilter filter){
		List<Services> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
