package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.SysAdmin;
import com.sa.ibiz.demo.demo.service.SysAdminService;
import com.sa.ibiz.demo.demo.service.dto.SysAdminSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/sysadmin")
public class SysAdminResource
{
	@Autowired
	private SysAdminService service;


	@GetMapping(value = "/{id}")
	public ResponseEntity<SysAdmin> get(@Validated @PathVariable String id){
		SysAdmin data=new SysAdmin();
		data.setSysadminid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("系统管理模块[get]操作发生错误","SysAdmin",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<SysAdmin> getDraft(@Validated @RequestBody SysAdmin data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("系统管理模块[getDraft]操作发生错误","SysAdmin","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/create")
	public ResponseEntity<SysAdmin> create(@Validated @RequestBody SysAdmin data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("系统管理模块[create]操作发生错误","SysAdmin",data.getSysadminid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<SysAdmin> update(@Validated @RequestBody SysAdmin data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("系统管理模块[update]操作发生错误","SysAdmin",data.getSysadminid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<SysAdmin> remove(@Validated @RequestBody SysAdmin data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("系统管理模块[remove]操作发生错误","SysAdmin",data.getSysadminid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/checkKey")
	public ResponseEntity<SysAdmin> checkKey(@Validated @RequestBody SysAdmin data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("系统管理模块[checkKey]操作发生错误","SysAdmin",data.getSysadminid().toString());
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<SysAdmin>> searchDefaultPage(@Validated @RequestBody SysAdminSearchFilter filter){
		Page<SysAdmin> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<SysAdmin>> listDefault(@Validated @RequestBody SysAdminSearchFilter filter){
		List<SysAdmin> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
