package com.sa.ibiz.demo.demo.rest;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sa.ibiz.demo.demo.domain.UserDict;
import com.sa.ibiz.demo.demo.service.UserDictService;
import com.sa.ibiz.demo.demo.service.dto.UserDictSearchFilter;
import com.sa.ibiz.demo.ibizutil.errors.BadRequestAlertException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import java.math.BigInteger;
import java.util.List;

@RestController
@RequestMapping("/demo/userdict")
public class UserDictResource
{
	@Autowired
	private UserDictService service;


	@PostMapping(value = "/create")
	public ResponseEntity<UserDict> create(@Validated @RequestBody UserDict data){
		boolean bRt=service.create(data);
		if(!bRt)
			throw new BadRequestAlertException("用户词典[create]操作发生错误","UserDict",data.getUserdictid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/update")
	public ResponseEntity<UserDict> update(@Validated @RequestBody UserDict data){
		boolean bRt=service.update(data);
		if(!bRt)
			throw new BadRequestAlertException("用户词典[update]操作发生错误","UserDict",data.getUserdictid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/remove")
	public ResponseEntity<UserDict> remove(@Validated @RequestBody UserDict data){
		boolean bRt=service.remove(data);
		if(!bRt)
			throw new BadRequestAlertException("用户词典[remove]操作发生错误","UserDict",data.getUserdictid().toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/getDraft")
	public ResponseEntity<UserDict> getDraft(@Validated @RequestBody UserDict data){
		boolean bRt=service.getDraft(data);
		if(!bRt)
			throw new BadRequestAlertException("用户词典[getDraft]操作发生错误","UserDict","");
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/checkKey")
	public ResponseEntity<UserDict> checkKey(@Validated @RequestBody UserDict data){
		boolean bRt=service.checkKey(data);
		if(!bRt)
			throw new BadRequestAlertException("用户词典[checkKey]操作发生错误","UserDict",data.getUserdictid().toString());
		return ResponseEntity.ok().body(data);
	}
	@GetMapping(value = "/{id}")
	public ResponseEntity<UserDict> get(@Validated @PathVariable String id){
		UserDict data=new UserDict();
		data.setUserdictid(id);;
		data=service.get(data);
		if(data==null)
			throw new BadRequestAlertException("用户词典[get]操作发生错误","UserDict",id.toString());
		return ResponseEntity.ok().body(data);
	}
	@PostMapping(value = "/reloadCurUser")
	public ResponseEntity<UserDict> reloadCurUser(@Validated @RequestBody UserDict data){
		service.reloadCurUser(data);
		return ResponseEntity.ok().body(data);
	}
    @PostMapping(value="/searchdefault")
	public ResponseEntity<Page<UserDict>> searchDefaultPage(@Validated @RequestBody UserDictSearchFilter filter){
		Page<UserDict> searchResult = service.searchDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}

	@PostMapping(value="/listdefault")
	public ResponseEntity<List<UserDict>> listDefault(@Validated @RequestBody UserDictSearchFilter filter){
		List<UserDict> searchResult = service.listDefault(filter);
		return ResponseEntity.ok().body(searchResult);
	}
}
